@@ -1,7 +1,7 @@
 /* baumbrl.c
  *
- * Copyright 2001, 2002 Sun Microsystems, Inc.,
- * Copyright 2001, 2002 BAUM Retec, A.G.
+ * Copyright 2001 - 2005 Sun Microsystems, Inc.,
+ * Copyright 2001 - 2005 BAUM Retec, A.G.
  *
  * This library is free software; you can redistribute it and/or
  * modify it under the terms of the GNU Library General Public
@@ -57,9 +57,12 @@
 typedef enum 
 {
     BAUMDT_GENERIC,
+    BAUMDT_POCKETVARIO24,
     BAUMDT_VARIO40,
+    BAUMDT_SUPERVARIO40,
     BAUMDT_VARIO20,
     BAUMDT_VARIO80,
+    BAUMDT_PRONTO,
     BAUMDT_DM80p,
     BAUMDT_INKA
 } BAUMDeviceType;
@@ -722,6 +725,9 @@ baum_brl_input_parser (gint new_val)
 					
 		    case BAUMDT_VARIO40:
 		    case BAUMDT_VARIO20:
+		    case BAUMDT_PRONTO:
+		    case BAUMDT_SUPERVARIO40:
+		    case BAUMDT_POCKETVARIO24:	
 			/* direct mapping, device has no other keys */
 			baumdd.cumulated_key_state = baumdd.key_state = new_val & 0x3F;	
 		    break;
@@ -1057,7 +1063,54 @@ baum_brl_open_device (gchar          *device_name,
 
 	rv = 1;
     }
+    
+    else if (strcmp ("PRONTO", device_name) == 0) 	
+    {
+	device->cell_count = 18;
+	device->display_count = 1;
+	device->displays[0].start_cell = 0;
+	device->displays[0].width = 18;
+	device->displays[0].type = BRL_DISP_MAIN;
+	device->input_type = BRL_INP_BITS;
+	device->key_count = 6;
+	
+	baumdd.hms_length = 5;	/* ??? */
+	baum_dev_type = BAUMDT_PRONTO;
 
+	rv = 1;
+    }
+    
+    else if (strcmp ("POCKETVARIO24", device_name) == 0) 	
+    {
+	device->cell_count = 24;
+	device->display_count = 1;
+	device->displays[0].start_cell = 0;
+	device->displays[0].width = 24;
+	device->displays[0].type = BRL_DISP_MAIN;
+	device->input_type = BRL_INP_BITS;
+	device->key_count = 6;
+	
+	baumdd.hms_length = 5;	/* ??? */
+	baum_dev_type = BAUMDT_POCKETVARIO24;
+
+	rv = 1;
+    }
+    else if (strcmp ("SUPERVARIO40", device_name) == 0) 	
+    {
+	device->cell_count = 40;
+	device->display_count = 1;
+	device->displays[0].start_cell = 0;
+	device->displays[0].width = 40;
+	device->displays[0].type = BRL_DISP_MAIN;
+	device->input_type = BRL_INP_BITS;
+	device->key_count = 6;
+	
+	baumdd.hms_length = 5;	/* ??? */
+	baum_dev_type = BAUMDT_SUPERVARIO40;
+
+	rv = 1;
+    }
+    
     else if (strcmp ("VARIO80", device_name) == 0) 	
     {		
 	device->cell_count = 84;
