@@ -1,7 +1,7 @@
 /* brlxmlapi.h
  *
- * Copyright 2001, 2002 Sun Microsystems, Inc.,
- * Copyright 2001, 2002 BAUM Retec, A.G.
+ * Copyright 2001 - 2005 Sun Microsystems, Inc.,
+ * Copyright 2001 - 2005 BAUM Retec, A.G.
  *
  * This library is free software; you can redistribute it and/or
  * modify it under the terms of the GNU Library General Public
@@ -19,13 +19,19 @@
  * Boston, MA 02111-1307, USA.
  */
 
-#ifndef _BRLXMLAPI_H
-#define _BRLXMLAPI_H
+#ifndef __BRLXMLAPI_H__
+#define __BRLXMLAPI_H__
 
-typedef void (*BRL_XML_INPUT_PROC) (char* buffer, int len);
+#include <glib.h>
 
-int  brl_xml_init (char* DeviceName, int Port, BRL_XML_INPUT_PROC InputCallbackProc);
-void brl_xml_terminate ();
-void brl_xml_output (char* buffer, int len);
+typedef void (*BRLXmlInputProc) (gchar *buffer,
+				 gint   len);
+
+gint  brl_xml_init     (gchar          *device_name,
+		       gint            port,
+		       BRLXmlInputProc input_callback_proc);
+void brl_xml_terminate (void);
+void brl_xml_output    (gchar          *buffer,
+                       gint            len);
 
 #endif
